==> axis2-1.8.0-src.zip: axis2-1.8.0/modules/jaxws/src/org/apache/axis2/jaxws/spi/Binding.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.axis2.jaxws.spi;

import org.apache.axis2.addressing.EndpointReference;
import org.apache.axis2.jaxws.core.MessageContext;

import javax.xml.ws.WebServiceFeature;

/**
 * 
 */
public interface Binding extends javax.xml.ws.Binding {
    public void setFeatures(WebServiceFeature... features);
    
    public WebServiceFeature getFeature(String id);
    
    public void configure(MessageContext messageContext, BindingProvider provider);
    
    public void setAxis2EndpointReference(EndpointReference epr);
    
    public void setAddressingNamespace(String addressingNamespace);
    
    public EndpointReference getAxis2EndpointReference();
    
    public String getAddressingNamespace();
}

==> axis2-2.0.0-src.zip: axis2-2.0.0/modules/jaxws/src/org/apache/axis2/jaxws/spi/Binding.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.axis2.jaxws.spi;

import org.apache.axis2.addressing.EndpointReference;
import org.apache.axis2.jaxws.core.MessageContext;

import jakarta.xml.ws.WebServiceFeature;

/**
 * 
 */
public interface Binding extends jakarta.xml.ws.Binding {
    public void setFeatures(WebServiceFeature... features);
    
    public WebServiceFeature getFeature(String id);
    
    public void configure(MessageContext messageContext, BindingProvider provider);
    
    public void setAxis2EndpointReference(EndpointReference epr);
    
    public void setAddressingNamespace(String addressingNamespace);
    
    public EndpointReference getAxis2EndpointReference();
    
    public String getAddressingNamespace();
}
